pub struct TextEdit {
pub range: TextRange,
pub new_text: String,
}Expand description
A text edit applied to the source, as typically received from an LSP.
Fields
range: TextRangeThe byte range in the old text to replace.
new_text: StringThe new text to insert in place of the range.
Implementations